@@ -1,10 +1,10 @@
 ##----------------------------------------------------------------------------
 ## PO Files Manipulation - ~/lib/Text/PO/Element.pm
-## Version v0.3.0
-## Copyright(c) 2023 DEGUEST Pte. Ltd.
+## Version v0.4.0
+## Copyright(c) 2024 DEGUEST Pte. Ltd.
 ## Author: Jacques Deguest <jack@deguest.jp>
 ## Created 2021/07/23
-## Modified 2024/12/07
+## Modified 2025/10/08
 ## All rights reserved
 ## 
 ## This program is free software; you can redistribute  it  and/or  modify  it
@@ -25,7 +25,7 @@ BEGIN
         fallback => 1,
     );
     use Text::Wrap ();
-    our $VERSION = 'v0.3.0';
+    our $VERSION = 'v0.4.0';
     use open ':std' => ':utf8';
 };
 
@@ -314,8 +314,8 @@ sub reference
     {
         if( $self->_is_array( $_[0] ) )
         {
-            ## Multi references:
-            ## colorscheme.cpp:79 skycomponents/equator.cpp:31
+            # Multi references:
+            # colorscheme.cpp:79 skycomponents/equator.cpp:31
             if( $self->_is_array( $_[0]->[0] ) )
             {
                 $self->{file} = [];
@@ -336,20 +336,20 @@ sub reference
             @$self{ qw( file line ) } = split( /:/, shift( @_ ), 2 );
         }
     }
-    return( '' ) if( !length( $self->{file} ) || !length( $self->{line} ) );
+    return( '' ) if( !length( $self->{file} ) );
     return( '' ) if( $self->_is_array( $self->{file} ) && !scalar( @{$self->{file}} ) );
     if( $self->_is_array( $self->{file} ) )
     {
         my @temp = ();
         for( my $i = 0; $i < scalar( @{$self->{file}} ); $i++ )
         {
-            push( @temp, join( ':', $self->{file}->[$i], $self->{line}->[$i] ) );
+            push( @temp, join( ':', $self->{file}->[$i], ( $self->_is_array( $self->{line} ) ? ( $self->{line}->[$i] // '' ) : '' ) ) );
         }
         return( join( ' ', @temp ) );
     }
     else
     {
-        return( join( ':', @$self{ qw( file line ) } ) );
+        return( join( ':', $self->{file}, ( $self->{line} // '' ) ) );
     }
 }
 
@@ -482,12 +482,25 @@ Text::PO::Element - PO Element
 
 =head1 VERSION
 
-    v0.3.0
+    v0.4.0
 
 =head1 DESCRIPTION
 
 This is the class for PO elements.
 
+A typical PO element might look like this:
+
+    white-space
+    #  translator-comments
+    #. extracted-comments
+    #: reference...
+    #, flag...
+    #| msgid previous-untranslated-string
+    msgid untranslated-string
+    msgstr translated-string
+
+See more information fromt he L<GNU documentation|https://www.gnu.org/software/gettext/manual/html_node/PO-File-Entries.html>
+
 =head2 CONSTRUCTOR
 
 =head2 new
@@ -550,6 +563,10 @@ The optional localised string in plural
 
 The optional context.
 
+The context serves to disambiguate messages with the same untranslated-string. It is possible to have several entries with the same untranslated-string in a PO file, provided that they each have a different context. Note that an empty context string and an absent msgctxt line do not mean the same thing.
+
+L<https://www.gnu.org/software/gettext/manual/html_node/Entries-with-Context.html>
+
 =item * C<fuzzy>
 
 The fuzzy flag set when the entry has been created but not yet translated
@@ -558,14 +575,20 @@ See also the L<GNU PO documentation|https://www.gnu.org/software/gettext/manual/
 
 =item * C<comment>
 
+    #  translator-comments
+
 The optional comment that can be added to provide some explanations to the translator
 
 =item * C<auto_comment>
 
+    #. extracted-comments
+
 The optional comment added automatically
 
 =item * C<flags>
 
+    #, flag...
+
 An optional set of flags, stored as an array reference
 
 For example:
@@ -579,7 +602,159 @@ For example:
 
 Here the flag would be C<c-format>
 
-See also the L<GNU PO documentation|https://www.gnu.org/software/gettext/manual/html_node/c_002dformat-Flag.html> and L<here|https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html#index-no_002dc_002dformat-flag>
+See also the L<GNU PO documentation|https://www.gnu.org/software/gettext/manual/html_node/c_002dformat-Flag.html> and L<here|https://www.gnu.org/software/gettext/manual/html_node/PO-Files.html#index-no_002dc_002dformat-flag>, and the L<list of flags|https://www.gnu.org/software/gettext/manual/html_node/Sticky-flags.html>
+
+Known flags are:
+
+=over 8
+
+=item * C<c-format> or C<no-c-format>
+
+The C<c-format> flag indicates that the untranslated string and the translation are supposed to be C format strings. The C<no-c-format> flag indicates that they are not C format strings, even though the untranslated string happens to look like a C format string (with ‘%’ directives). 
+
+=item * C<objc-format> or C<no-objc-format>
+
+Likewise for L<Objective C|https://www.gnu.org/software/gettext/manual/html_node/objc_002dformat.html>
+
+=item * C<c++-format> or C<no-c++-format>
+
+Likewise for L<C++|https://www.gnu.org/software/gettext/manual/html_node/c_002b_002b_002dformat.html>
+
+=item * C<python-format> or C<no-python-format>
+
+Likewise for L<Python|https://www.gnu.org/software/gettext/manual/html_node/python_002dformat.html>
+
+=item * C<python-brace-format> or C<no-python-brace-format>
+
+Likewise for L<Python brace|https://www.gnu.org/software/gettext/manual/html_node/python_002dformat.html>
+
+=item * C<java-format> or C<no-java-format>
+
+Likewise for L<Java MessageFormat format strings|https://www.gnu.org/software/gettext/manual/html_node/java_002dformat.html>
+
+=item * C<java-printf-format> or C<no-java-printf-format>
+
+Likewise for L<Java printf format strings|https://www.gnu.org/software/gettext/manual/html_node/java_002dformat.html>
+
+=item * C<csharp-format> or C<no-csharp-format>
+
+Likewise for L<C# Format Strings|https://www.gnu.org/software/gettext/manual/html_node/csharp_002dformat.html>
+
+=item * C<javascript-format> or C<no-javascript-format>
+
+Likewise for L<JavaScript Format Strings|https://www.gnu.org/software/gettext/manual/html_node/javascript_002dformat.html>
+
+=item * C<scheme-format> or C<no-scheme-format>
+
+Likewise for L<Scheme Format Strings|https://www.gnu.org/software/gettext/manual/html_node/scheme_002dformat.html>
+
+=item * C<lisp-format> or C<no-lisp-format>
+
+Likewise for L<Lisp Format Strings|https://www.gnu.org/software/gettext/manual/html_node/lisp_002dformat.html>
+
+=item * C<lisp-format> or C<no-lisp-format>
+
+Likewise for L<Lisp Format Strings|https://www.gnu.org/software/gettext/manual/html_node/lisp_002dformat.html>
+
+=item * C<elisp-format> or C<no-elisp-format>
+
+Likewise for L<Emacs Lisp Format Strings|https://www.gnu.org/software/gettext/manual/html_node/elisp_002dformat.html>
+
+=item * C<librep-format> or C<no-librep-format>
+
+Likewise for L<librep Format Strings|https://www.gnu.org/software/gettext/manual/html_node/librep_002dformat.html>
+
+=item * C<rust-format> or C<no-rust-format>
+
+Likewise for L<Rust Format Strings|https://www.gnu.org/software/gettext/manual/html_node/rust_002dformat.html>
+
+=item * C<go-format> or C<no-go-format>
+
+Likewise for L<Go Format Strings|https://www.gnu.org/software/gettext/manual/html_node/go_002dformat.html>
+
+=item * C<sh-format> or C<no-sh-format>
+
+Likewise for L<Shell Format Strings|https://www.gnu.org/software/gettext/manual/html_node/sh_002dformat.html>
+
+=item * C<sh-printf-format> or C<no-sh-printf-format>
+
+Likewise for L<Shell Format Strings|https://www.gnu.org/software/gettext/manual/html_node/sh_002dformat.html>
+
+=item * C<awk-format> C<no-awk-format>
+
+Likewise for L<awk Format Strings|https://www.gnu.org/software/gettext/manual/html_node/awk_002dformat.html>
+
+=item * C<lua-format> or C<no-lua-format>
+
+Likewise for L<Lua Format Strings|https://www.gnu.org/software/gettext/manual/html_node/lua_002dformat.html>
+
+=item * C<object-pascal-format> or C<no-object-pascal-format>
+
+Likewise for L<Object Pascal Format Strings|https://www.gnu.org/software/gettext/manual/html_node/object_002dpascal_002dformat.html>
+
+=item * C<modula2-format> or C<no-modula2-format>
+
+Likewise for L<Modula-2 Format Strings|https://www.gnu.org/software/gettext/manual/html_node/modula2_002dformat.html>
+
+=item * C<d-format> or C<no-d-format>
+
+Likewise for L<D Format Strings|https://www.gnu.org/software/gettext/manual/html_node/d_002dformat.html>
+
+=item * C<smalltalk-format> or C<no-smalltalk-format>
+
+Likewise for L<Smalltalk Format Strings|https://www.gnu.org/software/gettext/manual/html_node/smalltalk_002dformat.html>
+
+=item * C<qt-format> or C<no-qt-format>
+
+Likewise for L<Qt Format Strings|https://www.gnu.org/software/gettext/manual/html_node/qt_002dformat.html>
+
+=item * C<qt-plural-format> or C<no-qt-plural-format>
+
+Likewise for L<Qt plural forms Format Strings|https://www.gnu.org/software/gettext/manual/html_node/qt_002dplural_002dformat.html>
+
+=item * C<kde-format> or C<no-kde-format>
+
+Likewise for L<KDE Format Strings|https://www.gnu.org/software/gettext/manual/html_node/kde_002dformat.html>
+
+=item * C<boost-format> or C<no-boost-format>
+
+Likewise for L<Boost Format Strings|https://www.gnu.org/software/gettext/manual/html_node/boost_002dformat.html>
+
+=item * C<tcl-format> or C<no-tcl-format>
+
+Likewise for L<Tcl Format Strings|https://www.gnu.org/software/gettext/manual/html_node/tcl_002dformat.html>
+
+=item * C<perl-format> or C<no-perl-format>
+
+Likewise for L<Perl Format Strings|https://www.gnu.org/software/gettext/manual/html_node/perl_002dformat.html>
+
+=item * C<perl-brace-format> or C<no-perl-brace-format>
+
+Likewise for L<Perl brace Format Strings|https://www.gnu.org/software/gettext/manual/html_node/perl_002dformat.html>
+
+=item * C<php-format> or C<no-php-format>
+
+Likewise for L<PHP Format Strings|https://www.gnu.org/software/gettext/manual/html_node/php_002dformat.html>
+
+=item * C<gcc-internal-format> or C<no-gcc-internal-format>
+
+Likewise for the L<GCC internal Format Strings|https://www.gnu.org/software/gettext/manual/html_node/gcc_002dinternal_002dformat.html>
+
+=item * C<gfc-internal-format> or C<no-gfc-internal-format>
+
+Likewise for the L<GNU Fortran Compiler internal Format Strings|https://www.gnu.org/software/gettext/manual/html_node/gfc_002dinternal_002dformat.html> in sources up to GCC 14.x. These flags are deprecated.
+
+=item * C<ycp-format> or C<no-ycp-format>
+
+Likewise for L<YCP Format Strings|https://www.gnu.org/software/gettext/manual/html_node/ycp_002dformat.html>
+
+Other flags, assigned by the programmer, are:
+
+=item * C<no-wrap>
+
+This flag influences the presentation of the entry in the PO file. By default, when a PO file is output by a GNU gettext program and the option ‘--no-wrap’ is not specified, message lines that exceed the output page width are split into several lines. This flag inhibits this line breaking for the entry. This is useful for entries whose lines are close to 80 columns wide.
+
+=back
 
 =item * C<plural>
 
@@ -749,6 +924,8 @@ Sets or gets the L<Text::PO> object associated with this element. Best that you
 
 =head2 reference
 
+    #: lib/error.c:116
+
 Given an array reference or a string separated by ':', it sets the file and line number for this element object.
 
 =head2 wrap
